#close_button, window>grid>box>button, #version{
    margin: 10px;
}

#modes {
    font-size: x-large;
    font-weight: bold;
    margin-top: 20px;
    margin-bottom: 10px;
}

stack>grid {
    padding: 20px;
    padding-top: 10px;
}

stack>grid>grid, scrolledwindow grid{
    padding: 20px;
    padding-top: 10px;
}
 
window notebook{
    margin-left: 45px;
    margin-right: 45px;
    margin-top: 40px;
    margin-bottom: 0px;
} 

#smaller_label label {
    font-size: small;
}

/* ------------------- */
#radio_grid, stack>grid{
    margin-top: 10px;
}

#link{
    background: transparent;
    box-shadow: none;
    font-weight: bold;
}

#facebook_icon {
    padding-left: 15px;
}

#facebook {
    padding-right: 15px;
}

scrolledwindow *{
    border: none;
    border-image: none;
}
 
window>grid>box>button {
    margin: 10px;
    background: rgb(23, 24, 23);
    border: 1px solid rgb(39, 161, 15);
    border-style: outset;
    border-radius: 5px;
}

window>grid>box>button:hover {    
    outline-style: solid;
    outline-offset: -2px;
    outline-width: 2px;
}

combobox>box>entry, entry {
    background-color: white;
    background: white;
    color: black;
    border-radius: 0px;
    border: none;
}

combobox>box>button:disabled {
    background-color: rgb(0, 100, 0);
    background: rgb(0, 100, 0);
    color: white;
}

radio, radiobutton, radiobutton:checked, radiobutton:selected{
    color: green;
    background: transparent;
    
}

radiobutton:checked, radiobutton:active{
    border: none;
}

window grid label {
    color: white;
}

scale, scale *{
    color:white;
}

/* WINDOW */
window{
    background-color: rgb(0, 0, 0);
}

notebook stack button {
    background: green;
    border: none;
    border-radius: 0px;
    box-shadow: none;
    background-size: 100% 100%;
    background-repeat: no-repeat;
}

notebook stack button:hover {
    background: rgb(0, 95, 0);
    border: none;
    border-radius: 0px;
    box-shadow: none;
    background-size: 100% 100%;
    background-repeat: no-repeat;
}

notebook, notebook > *{
    background-color: transparent;
}

notebook stack {
    background-image: url('../../images/interface/stack-background.png');
    background-repeat: no-repeat;
    background-size: 100% 100%;
    
}


header > tabs label {
    border: none;
    padding-left: 20px;
    padding-right: 20px;
}

combobox>box>button {
    background-color: rgb(2, 126, 2);
    background: green;
    color: white;
}

notebook header, notebook, stack{
    border: 1px solid rgb(0, 0, 0);
    background-color: transparent;
}

/* TABS */

header > tabs > tab {
    background-image: url('../../images/interface/tab.png');
    border: none;
    box-shadow: none;
    background-size: 100% 100%;
    background-color: transparent;
}

header > tabs > tab:hover, header > tabs > tab:checked {
    background-image: url('../../images/interface/current-tab.png');
    border: none;
    background-color: transparent;
}

#terminal label{
    color: black;
}
#terminal {
    background-color: white;
}

#terminal box, #warn>box, 
#terminal scrolledwindow{
    padding: 10px;
}

#terminal scrolledwindow {
    background-color: black;
}
#warn>box *{
    background-color: transparent;
}

/* notebook {
    margin: 0px;
} */

/* notebook grid>grid {
    
} */
